#!/bin/bash
Address="https://localhost"

Login=""
Password=""
Connection="default"
CheckTimeout="20"

AppName=TessaDesktopApp

get_script_dir () {
     SOURCE="${BASH_SOURCE[0]}"
     # while $SOURCE is a symlink, resolve it
     while [ -h "$SOURCE" ]; do
          DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
          SOURCE="$( readlink "$SOURCE" )"
          # if $SOURCE was a relative symlink (so no "/" as prefix, need to resolve it relative to the symlink base directory
          [[ $SOURCE != /* ]] && SOURCE="$DIR/$SOURCE"
     done
     DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
     echo "$DIR"
}
CurrentDir="$(get_script_dir)"

Applications="$CurrentDir/app"

# here must be path to tadmin executable
Tools="$CurrentDir/tools"
cd "$Tools"

cleanup () {
    :
}

exit_on_error () {
	ErrorLevel="$?"
	if [ "$ErrorLevel" != "0" ]; then
		cleanup
		echo
		echo "Publication failed with error code: $ErrorLevel"
		echo "See the details in log file: $Tools/log.txt"
		exit 1
	fi
}

#Start
echo "This script will publish $AppName"
echo
echo "Please check connection string prior to publication in configuration file:"
echo "$Tools/app.json"
echo
echo "[Address] = $Address"
echo
read -n1 -r -p "Press any key to begin publication or Ctrl+C to exit..." key

echo
echo "Publishing $AppName"
echo

echo " > Checking connection to web service"
./tadmin CheckService "-a:$Address" "-u:$Login" "-p:$Password" "-timeout:$CheckTimeout" -q
exit_on_error

echo " > Publishing $AppName"
rm -f "$Applications/*.jcard"
./tadmin PackageApp "$Applications/$AppName/$AppName.dll" -64bit -api2 "-a:tessadesktopapp" "-out:$Applications/$AppName.jcard" -q
exit_on_error
./tadmin PackageApp "$Applications/$AppName32/$AppName.dll" -api2 "-a:tessadesktopapp" "-out:$Applications/$AppName32.jcard" -q
exit_on_error
./tadmin ImportCards "$Applications" "-a:$Address" "-u:$Login" "-p:$Password" -q
exit_on_error
rm -f "$Applications/*.jcard"

cleanup

echo
echo "$AppName is published."
exit 0
