﻿using System;
using System.Linq;
using System.Threading.Tasks;
using Tessa.Platform.Initialization;
using Tessa.Platform.Validation;
using Tessa.Roles;

namespace Tessa.Extensions.Server.Initialization
{
    /// <summary>
    /// Серверное расширение, проверяющее при запуске приложения
    /// входит ли текущий пользователь в роль "Регистраторы".
    /// </summary>
    public sealed class AbUserAccessServerInitializationExtension
        : ServerInitializationExtension
    {
        #region Fields

        /// <summary>
        /// Репозиторий ролей.
        /// </summary>
        private IRoleRepository roleRepository;

        /// <summary>
        /// Идентификатор статической роли "Регистраторы".
        /// </summary>
        private static readonly Guid registratorsRoleID = new Guid("0071b103-0ffa-49da-8776-53b9c654d815");

        #endregion

        #region Constructors
        
        /// <summary>
        /// Создаёт новый объект расширения проверки ролей.
        /// </summary>
        /// <param name="roleRepository">Ролевой репозиторий.</param>
        public AbUserAccessServerInitializationExtension(IRoleRepository roleRepository)
        {
            this.roleRepository = roleRepository;
        }

        #endregion

        #region Base overrides

        /// <inheritdoc/>
        public override async Task AfterRequest(IServerInitializationExtensionContext context)
        {
            if (!context.RequestIsSuccessful)
            {
                return;
            }

            // проверка
            var users = await roleRepository.GetUsersAsync(registratorsRoleID, context.CancellationToken);
            if (users.All(p => p.UserID != context.Session.User.ID))
            {
                context.ValidationResult.AddError(this, "Доступ запрещён.");
            }
        }

        #endregion
    }
}
